@@ -23,9 +23,6 @@ class Prediction:
         # the number of data points in the future to be predicted, max 1000
         self.data_points = 20
 
-        # True if the final output needs to be stored as graph, False otherwise
-        self.plot = True
-
         self.model_params = dict(
             arima=dict(
                 start_p=1,
@@ -47,7 +44,6 @@ class Prediction:
             svr=dict(kernel="rbf", C=1e3, gamma=0.1),
         )
         self.final_predicted_df = None
-        self.plot_df = None
 
     def __init_class_vars(
         self,
@@ -56,7 +52,6 @@ class Prediction:
         label: str,
         date_column: str,
         data_points: int,
-        plot: bool,
     ):
 
         # either all to predict using all the models else one of arima, svr or linear
@@ -82,9 +77,6 @@ class Prediction:
         # the number of data points in the future to be predicted, max 1000
         self.data_points = data_points
 
-        # True if the final output needs to be stored as graph, False otherwise
-        self.plot = plot
-
     def __createmodel(self, model_type, df):
 
         if model_type == "ARIMA":
@@ -131,7 +123,7 @@ class Prediction:
     def __modelling_prediction(self, df):
         if self.prediction_type == "all":
             output_dfs = [
-                df,
+                df.copy(),
             ]
             models_dict = {}
             predicted_cols = []
@@ -148,7 +140,7 @@ class Prediction:
                 output_dfs.append(predicted_df)
         else:
             output_dfs = [
-                df,
+                df.copy(),
             ]
             models_dict = {}
             predicted_cols = []
@@ -184,7 +176,6 @@ class Prediction:
         label: str = "Close",
         date_column: str = "Date",
         data_points: int = 20,
-        plot: bool = False,
     ):
         # initializes the class variables
         self.__init_class_vars(
@@ -193,20 +184,22 @@ class Prediction:
             label=label,
             date_column=date_column,
             data_points=data_points,
-            plot=plot,
         )
 
         # modelling and making the predictions
         output_dfs = None
         predicted_cols = None
+        group = None
         if "Company" in dataset.columns:
+            group = ["Date", "Company"]
             predicted_cols, output_dfs = self.__multi_company()
         else:
+            group = ["Date"]
             predicted_cols, output_dfs = self.__modelling_prediction(dataset)
         res = pd.concat(output_dfs)
         res = res.reset_index(drop=True)
         agg = {i: ("sum" if i in predicted_cols else "first") for i in res.columns}
-        res = res.groupby("Date", as_index=False, dropna=False).agg(agg)
+        res = res.groupby(group, as_index=False, dropna=False).agg(agg)
         res["COMPOUND"] = res[predicted_cols].mean(axis=1)
         res["COMPOUND"] = res["COMPOUND"].replace(0.000000, np.nan)
         for col in predicted_cols:
